% Modal Interferometer Simulation Tool (MIST) - Gabriele Vajente (April 2010)
%
% Return the reflection coefficient of a Fabry-Perot cavity
%
% function F = FX(cav, dL, f)
%
%    cav = cavity structure
%    dL  = cavity detuning in meters
%    f   = frequency detuning (Hz)

function F = FX(cav, dL, f)
c = 299792458;

% get number of modes
N = size(cav.modes,1);
U = eye(N);

% tune propagator
k = 2*pi / 1.064e-6;
w = 2*pi*f;

PL = exp(1j*k*dL) * exp(-1j * w/c * cav.L) * cav.PL;
PL_Re_PL = PL * cav.Re * PL;

%compute reflection coefficient
%F = 1j * cav.Lens * (cav.Ri' + cav.Ti * PL * cav.Re * PL * inv(U + cav.Ri * PL * cav.Re * PL) * cav.Ti) * cav.Lens;
F = 1j * cav.Lens * (cav.Ri' + cav.Ti * PL_Re_PL / (U + cav.Ri * PL_Re_PL) * cav.Ti) * cav.Lens;
