% Modal Interferometer Simulation Tool (MIST) - Gabriele Vajente (April 2010)
%
% Return one of the Michelson operators
%
% M = MSS(itf, f)
%
%     itf = itf structure
%     f   = frequency


function [MSS, MAA, MSA, MAS] = Michelson(itf, f)
c = 299792458;

% compute propagator ignoring Gouy phase in Schnupp asymmetry
k = 2*pi / 1.064e-6;
w = 2*pi*f;
itf.PLm = sqrt(1j) * exp(1j * k * itf.MICH + 1j * w / c * itf.Schnupp/2);

% compute Michelson operator

NCAV = itf.PLm    * FX(itf.ncav, 0.5*(itf.CARM + itf.DARM), f) * itf.PLm;
WCAV = itf.PLm^-1 * FX(itf.wcav, 0.5*(itf.CARM - itf.DARM), f) * itf.PLm^-1;

MSS =  0.5  * (NCAV - WCAV);
%MAA = -0.5  * (NCAV - WCAV);
MAA = -MSS;
MSA =  0.5j * (NCAV + WCAV);
%MAS=  0.5j * (NCAV + WCAV);
MAS =  MSA;



