% Modal Interferometer Simulation Tool (MIST) - Gabriele Vajente (April 2010)
%
% Build a Fabry-Perot cavity with all needed structures
%
% function cav = build_cavity(R1_0, R2_0, L, R1, R2, r1, r2, l1, l2, flens, thetai, thetae, modes)
%
% R1_0, R2_0     = ideal radii of curvature of mirrors
% L              = cavity lenght
% R1, R2         = real radii of curvature
% r1, r2         = amplitude reflectivites of mirrors
% l1, l2         = losses of mirrors
% flens          = focal of input mirror lens
% thetai, thetae = tilts of input and end mirrors
% modes          = list of mdoes to be used

function cav = build_cavity_tilted(R1_0, R2_0, L, R1, R2, r1, r2, l1, l2, flens, thetai, thetae, modes)
    
    global rmir npt thr

    % first compute geometrical parameters and store modes
    cav = cavity_mode(R1_0, R2_0, L);
    cav.modes = modes;
    
    % then compute reflection matrices
    cav.Ri = tilted_mirror_reflection(R1, thetai, R1_0, cav.w1, modes, rmir, npt, thr);
    cav.Re = tilted_mirror_reflection(R2, thetae, R2_0, cav.w2, modes, rmir, npt, thr);
    
    % transmission of input mirror
    cav.Ti = eye(size(modes,1));
    
    % propagator at cavity resonance (only Gouy phase relative to 00 mode)
    cav.PL = diag(1j * exp(1j * sum(modes') * cav.phig));
    
    % reflection and transmission scalar coefficient
    cav.Ri = cav.Ri * r1;
    cav.Re = cav.Re * r2;
    cav.Ti = cav.Ti * sqrt(1 - l1 - r1^2);
    
    % create input mirror thermal lens
    if flens > 1e10
        cav.Lens = eye(size(modes,1));
    else
        cav.Lens = lens(flens, cav.w1, modes, rmir, npt, thr);
    end
    
