% Modal Interferometer Simulation Tool (MIST) - Gabriele Vajente (April 2010)
%
% Compute  error signals to lock dual recycled interferometer
%
% [eprcl, ecarm, emich, edarm, esrcl] = error_signals_norm(itf, lock)
%
%       itf  = interferometer structure
%       lock = structure containing lock parameters 
%               gcarm, gprcl, gmich, gdarm, gsrcl: loop gains 
%                   (zero means not locked)
%               tolcarm, toldarm, tolmich, tolprcl, tolsrc: maximum tolerances
%                                                     for error signals
%

function [eprcl, ecarm, emich, edarm, esrcl] = error_signals(itf, lock)

    % compute fields
    [crc, cdf, cref] = dualrecycled_fields_forlock(itf, 0);
    [u1rc, u1df, u1ref] = dualrecycled_fields_forlock(itf,  itf.fmod1);
    [l1rc, l1df, l1ref] = dualrecycled_fields_forlock(itf, -itf.fmod1);
    [u2rc, u2df, u2ref] = dualrecycled_fields_forlock(itf,  itf.fmod2);
    [l2rc, l2df, l2ref] = dualrecycled_fields_forlock(itf, -itf.fmod2);
    
    % compute AC signals
    [prc_p, prc_q]   = ac(crc(:,1), u1rc(:,1), l1rc(:,1), 0.1, 90);
    [ref_p, ref_q]   = ac(cref(:,1), u1ref(:,1), l1ref(:,1), 0.1, 90);
    [prc_p2, prc_q2] = ac(crc(:,1), u2rc(:,1), l2rc(:,1), 0.1, 90);
    
    % build error signals
    eprcl = lock.gprcl * ref_p;
    ecarm = lock.gcarm * prc_p;
    edarm = lock.gdarm * (abs(cdf(1,1))^2 - 8e-4);
    emich = lock.gmich * prc_q2;
    esrcl = lock.gsrcl * prc_p2;
    
