% Modal Interferometer Simulation Tool (MIST) - Gabriele Vajente (April 2010)
%
% Compute  error signals to lock dual recycled interferometer
%
% [eprcl, ecarm, emich, edarm] = error_signals_virgo(itf, lock, ph)
%
%       itf  = interferometer structure
%       lock = structure containing lock parameters 
%               gcarm, gprcl, gmich, gdarm: loop gains 
%                   (zero means not locked)
%               tolcarm, toldarm, tolmich, tolprcl: maximum tolerances
%                                                     for error signals
%       ph   = demodulation phases [phase_df, phase_prc, phase_ref]
%

function [eprcl, ecarm, emich, edarm] = error_signals_virgo(itf, lock, ph)

    % compute fields
    [crc, cdf, cref] = dualrecycled_fields_forlock(itf, 0);
    [u1rc, u1df, u1ref] = dualrecycled_fields_forlock(itf,  itf.fmod1);
    [l1rc, l1df, l1ref] = dualrecycled_fields_forlock(itf, -itf.fmod1);
    
    
    % compute AC signals
    [prc_p, prc_q]   = ac(crc(:,1), u1rc(:,1), l1rc(:,1), 0.1, ph(2));
    [ref_p, ref_q]   = ac(cref(:,1), u1ref(:,1), l1ref(:,1), 0.1, ph(3));
    [df_p, df_q]   = ac(cdf(:,1), u1df(:,1), l1df(:,1), 0.1, ph(1));
    
    % build error signals
    eprcl = lock.gprcl * ref_p;
    ecarm = lock.gcarm * prc_p;
    edarm = lock.gdarm * df_p;
    emich = lock.gmich * prc_q;
    
