% Modal Interferometer Simulation Tool (MIST) - Gabriele Vajente (April 2010)
%
% Auxiliary function used for pseudo-lock. Compute error signal for a given 
% position of CARM and PRCL, looking for the maximum of USB+LSB
%
% err = maximize_sb2(itf, zprcl, zcarm)
% 
%       itf   = interferometer structure
%       zprcl = prcl tuning in pm (1e-12 m)
%       zcarm = carm tuning in pm (1e-12 m)
%

function err = maximize_sb2(itf, zprcl, zcarm)
    itf.PRCL = 1e-12*zprcl;
    itf.CARM = 1e-12*zcarm;
    itf.DARM = 0;
    itf.MICH = 0;
    
    Urc = dualrecycled_fields_fast(itf, +itf.fmod1);
    Lrc = dualrecycled_fields_fast(itf, -itf.fmod1);
    
    err = abs(Urc(1,1))^2 + abs(Lrc(1,1))^2;
    
   
