% Modal Interferometer Simulation Tool (MIST) - Gabriele Vajente (April 2010)
%
% Return the reflection matrix for a mirror with mis-matched
% radius of curvature, using a given mode basis
% 
% M = mirror_reflection_map(mapfile, s, c, w, modes)
%
%     mapfile = phase map filename
%     c       = indexes of optical center
%     s       = step size of map
%     w       = beam size at mirror
%     R       = beam curvature at mirror
%     Rc      = mirror radius of curvature (with respect to which the
%                                           map is defined)
%     modes   = list of all modes to be used in [n,m] format

function M = mirror_reflection_map(mapfile, s, c, w, R, Rc, modes)
    tic;
    k = 2*pi / 1.064e-6;

    % load map file
    map = load(mapfile);
    map = -map * 1e-9;
    x = -((1:size(map,2)) - c(2)) * s;
    y = ((1:size(map,1)) - c(1)) * s;
    
    [x,y] = meshgrid(x,y);
    dxdy = s*s;
    
    r2 = x.^2 + y.^2;
    Z = r2/2 * (1/R - 1/Rc);
    
    map = map + Z;
    
    % build Gaussian weight and phase
    g = exp(2j*k*map - 2*r2/w^2);
    
    M = overlap_hermite(x, y, w, w, w, w, modes, 2 / pi * dxdy * g, thr); 
    