% Modal Interferometer Simulation Tool (MIST) - Gabriele Vajente (April 2010)
%
% Return the reflection matrix for a mirror with mis-matched
% radius of curvature, using a given mode basis
% 
% M = mirror_transmission_map(mapfile, s, c, w, modes)
%
%     mapfile = phase map filename
%     c       = indexes of optical center
%     s       = step size of map
%     w       = beam size at mirror
%     modes   = list of all modes to be used in [n,m] format

function M = mirror_transmission_map(mapfile, s, c, w, modes)
    tic;
    k = 2*pi / 1.064e-6;
    n = 1.45;

    % load map file
    map = load(mapfile);
    map = 1e-9 * map;
    x = ([1:size(map,2)] - c(2)) * s;
    y = ([1:size(map,1)] - c(1)) * s;
    
    [x,y] = meshgrid(x,y);
    dxdy = s*s;
        
    % build Gaussian weight and phase
    r2 = x.^2 + y.^2;
    g = exp(1j*k*(n-1)*map - 2*r2/w^2);
    
    M = overlap_hermite(x, y, w, w, w, w, modes, 2 / pi * dxdy .* g, thr);  
