% Modal Interferometer Simulation Tool (MIST) - Gabriele Vajente (April 2010)
%
% Return the transmission matrix for the residual lens computed from
% TCS phase maps (read from file)
% 
% M = tcs_lens(filename, dx, w, modes, r, thr)
%
%     filename = phase map datafile
%     dx       = transversal dimension
%     w        = beam size at lens
%     modes    = list of all modes to be used in [n,m] format
%     r        = radius of lens t be used
%     thr      = threshold

function M = tcs_lens(filename, dx, w, modes, r, thr)
    %tic;
    k = 2*pi / 1.064e-6;

    % load phase map
    pm = load(filename);
    pm(isnan(pm)) = 0;
    npt = sqrt(length(pm));
    
    % build integration grid
    [x,y] = meshgrid(linspace(-dx/2,dx/2,npt),linspace(-dx/2,dx/2,npt));
    dxdy = (2*dx/2 / (npt - 1))^2;
    
    % build phase map
    PM = reshape(pm, npt, npt);
    
    % build Gaussian weight
    r2 = x.^2 + y.^2;
    g = exp(1j*PM - 2*r2/w^2);
    
    % compute matrix for each mode
    M = overlap_hermite(x, y, w, w, w, w, modes, 2 / pi * dxdy * g, thr);          
