% Modal Interferometer Simulation Tool (MIST) - Gabriele Vajente (April 2010)
%
% Return the transmission matrix for the residual lens computed from
% TCS phase maps (passed as argument)
% 
% M = tcs_lens2(phase, rcp, w, modes, r, thr)
%
%     phase    = phase map (single direction)
%     rcp      = radius of phase map
%     w        = beam size at lens
%     modes    = list of all modes to be used in [n,m] format
%     r        = radius of lens t be used
%     thr      = threshold

function M = tcs_lens2(phase, rcp, w, modes, r, thr)
    %tic;
    k = 2*pi / 1.064e-6;

    % load phase map
    npt = length(phase);
    dx = max(rcp);
    
    % build integration grid
    [x,y] = meshgrid(linspace(-dx,dx,npt),linspace(-dx,dx,npt));
    dxdy = (2*dx / (npt - 1))^2;
    
    % build Gaussian weight
    r2 = x.^2 + y.^2;
    g = exp(-2*r2/w^2);
    
    % build phase map
    PM = zeros(npt, npt);
    for i=1:npt
        for j=1:npt
            PM(i,j) = interp1(rcp, phase, sqrt(r2(i,j)));
            if isnan(PM(i,j))
                PM(i,j) = 0;
            end
        end
    end
    
    M = overlap_hermite(x, y, w, w, w, w, modes, 2 / pi * dxdy * g.* exp(1j*PM), thr);    
    